@@ -5,8 +5,7 @@
 import os
 import threading
 import multiprocessing
-from utils.chunks import get_chunks
-
+from hhcp.utils.chunks import get_chunks
 
 def cp_dir(directory, destination, force):
     class myThread(threading.Thread):
